"""
fake-open: Library for testing opening writable files.


Copyright (c) 2016 Leiden University Medical Center <humgen@lumc.nl>
Copyright (c) 2016 Jeroen F.J. Laros <J.F.J.Laros@lumc.nl>

Licensed under the MIT license, see the LICENSE file.
"""
from .fake_open import FakeOpen, md5_check, make_fake_file


__version_info__ = ('0', '0', '1')

__version__ = '.'.join(__version_info__)
__author__ = 'LUMC, Jeroen F.J. Laros'
__contact__ = 'J.F.J.Laros@lumc.nl'
__homepage__ = 'https://git.lumc.nl/j.f.j.laros/fake-open'

usage = __doc__.split('\n\n\n')


def doc_split(func):
    return func.__doc__.split('\n\n')[0]


def version(name):
    return '{} version {}\n\nAuthor   : {} <{}>\nHomepage : {}'.format(
        name, __version__, __author__, __contact__, __homepage__)



from hashlib import md5
from io import StringIO


def md5_check(data, md5sum):
    return md5(data.encode()).hexdigest() == md5sum


def make_fake_file(name, content):
    handle = StringIO()
    handle.name = name
    handle.writelines(content)
    handle.seek(0)
    return handle


class FakeOpen(object):
    def __init__(self):
        self.handles = {}

    def open(self, name, attr=''):
        """
        Open a fake file.
        
        This handle can not be closed because we want to inspect the content
        even after close() was called.

        :arg str name: Name of the file.
        :arg str attr: Open attributes (ignored).

        :returns stream: Fake file handle.
        """
        handle = StringIO()
        handle.name = name
        handle.close = lambda: None
        self.handles[name] = handle
        return handle
